summaryrefslogtreecommitdiffstats
path: root/karm/preferences.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'karm/preferences.cpp')
-rw-r--r--karm/preferences.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/karm/preferences.cpp b/karm/preferences.cpp
index 6544931a..1dd13625 100644
--- a/karm/preferences.cpp
+++ b/karm/preferences.cpp
@@ -251,7 +251,7 @@ TQString Preferences::userRealName() const { return _userRealNa
//---------------------------------------------------------------------------
void Preferences::load()
{
- KConfig &config = *kapp->config();
+ TDEConfig &config = *kapp->config();
config.setGroup( TQString::fromLatin1("Idle detection") );
_doIdleDetectionV = config.readBoolEntry( TQString::fromLatin1("enabled"),
@@ -286,7 +286,7 @@ void Preferences::load()
void Preferences::save()
{
- KConfig &config = *TDEGlobal::config();
+ TDEConfig &config = *TDEGlobal::config();
config.setGroup( TQString::fromLatin1("Idle detection"));
config.writeEntry( TQString::fromLatin1("enabled"), _doIdleDetectionV);
@@ -311,23 +311,23 @@ void Preferences::save()
config.sync();
}
// HACK: this entire config dialog should be upgraded to KConfigXT
bool Preferences::readBoolEntry( const TQString& key )
{
- KConfig &config = *TDEGlobal::config();
+ TDEConfig &config = *TDEGlobal::config();
return config.readBoolEntry ( key, true );
}
void Preferences::writeEntry( const TQString &key, bool value)
{
- KConfig &config = *TDEGlobal::config();
+ TDEConfig &config = *TDEGlobal::config();
config.writeEntry( key, value );
config.sync();
}
void Preferences::deleteEntry( const TQString &key )
{
- KConfig &config = *TDEGlobal::config();
+ TDEConfig &config = *TDEGlobal::config();
config.deleteEntry( key );
config.sync();
}
@@ -311,23 +311,23 @@ void Preferences::save()
config.sync();
}
-// HACK: this entire config dialog should be upgraded to KConfigXT
+// HACK: this entire config dialog should be upgraded to TDEConfigXT
bool Preferences::readBoolEntry( const TQString& key )
{